@@ -1,6 +1,8 @@
+import json
 import os
 
 import pandas as pd
+from inspect import getfullargspec
 
 from . import settings
 from .handlers import BaseReader, BaseAnswer
@@ -43,7 +45,7 @@ def _shorted_path(path):
             i-=1
         else:
             i+=1
-    return l
+    return os.path.join(*l)
 
 
 
@@ -94,3 +96,56 @@ def create_test(fct_to_test, case, case_name) -> TestyRunner:
     outputs = _extract_outputs(case)
     ans = TestyRunner(run_function=run_fct_c, check_functions=outputs, case_name=case_name)
     return ans
+
+
+
+def get_names_for_args(len_args,kwargs_names,fct):
+    ans=[None]*len_args
+    if len_args==0:
+        return ans
+    t2 = getfullargspec(fct)
+    i=0
+    for name in t2.args:
+        if name not in kwargs_names:
+            ans[i]=name
+            i+=1
+            if i==len_args:
+                return ans
+    return ans
+
+def wrapper_to_test(fct):
+    def f3(*args, **kwargs):
+        no_name_args_nb=len(args)
+        t3=get_names_for_args(no_name_args_nb,kwargs.keys(),fct)
+        nb_args=no_name_args_nb+len(kwargs)
+        desc=pd.DataFrame(index=range(nb_args),columns=[settings.INPUT_META_VAR_COL,settings.INPUT_META_NAMED_COL])
+        args_list=list()
+        i=0
+        for arg in args:
+            args_list.append(arg)
+            desc.loc[i,settings.INPUT_META_NAMED_COL]=False
+            desc.loc[i,settings.INPUT_META_VAR_COL]=t3[i]
+            i+=1
+        for k,arg in kwargs.items():
+            args_list.append(arg)
+            desc.loc[i, settings.INPUT_META_NAMED_COL] = True
+            desc.loc[i,settings.INPUT_META_VAR_COL]=k
+            i += 1
+        print(desc)
+        ans= fct(*args,**kwargs)
+        return ans
+    return f3
+def bulk_seriazible(x):
+    try:
+        d=json.dumps(x)
+        return len(d)<500
+    except:
+        return False
+
+d={"x1":"writer_1",
+ int:"writer2",
+ bulk_seriazible:"writer3",
+ }
+
+def create_test_case(var_list,descr,writer_dict):
+    pass
