@@ -4,6 +4,6 @@ import pandas as pd
 
 
 class CsvReader(BaseReader):
-    def read(self, file_name, var_name):
-        df=pd.read_csv(file_name)
+    def read(self, complete_file_name, var_name):
+        df = pd.read_csv(complete_file_name)
         return df
